function [res1, res2] = spdiags2(arg1, arg2, arg3, arg4)
%SPDIAGS2 Sparse matrix formed from diagonals specifying starting subscripts.
%   Syntax similar to spdiags, but arg2 must be an n-by-2 matrix where n is
%   the number of columns of arg1. Each row of arg2 specifies the starting
%   position of each column of arg1. Unlike spdiags, the standard diagonal
%   matrix starts at (1,1) (in spdiags, it is 0).
%   Example:
%   >> full(spdiags2([1 6 11; 2 7 12; 3 8 13; 4 9 14; 5 10 15], [1 1; 2 1; 1 3], 5, 5))
%   > [1     0    11     0     0
%      6     2     0    12     0
%      0     7     3     0    13
%      0     0     8     4     0
%      0     0     0     9     5]
%   * First column starts from (1,1); second (2,1); third (1,3).

    assert(ismatrix(arg2) && size(arg2, 2) == 2)

    [m, n] = size(arg1);
    arg1_ = zeros(max(size(arg1) + [max(arg2(:,2))-1,0], [max(arg3,arg4),0]));
    for i = 1 : n
        k = arg2(i, 2);
        arg1_(max(k,1):k+m-1, i) = arg1(1+max(1-k,0):m, i);
    end

    [varargout{1 : nargout}] = spdiags(arg1_, arg2(:,2)-arg2(:,1), arg3, arg4);

    res1 = varargout{1};
    if nargout > 1
        res2 = varargout{2};
    end

end
